@@ -807,7 +807,9 @@ VERSIONED_FIELDS = {
     'boot_mode': versions.MINOR_75_NODE_BOOT_MODE,
     'secure_boot': versions.MINOR_75_NODE_BOOT_MODE,
     'shard': versions.MINOR_82_NODE_SHARD,
-    'parent_node': versions.MINOR_83_PARENT_CHILD_NODES
+    'parent_node': versions.MINOR_83_PARENT_CHILD_NODES,
+    'firmware_interface': versions.MINOR_86_FIRMWARE_INTERFACE,
+    'service_step': versions.MINOR_87_SERVICE
 }
 
 for field in V31_FIELDS:
@@ -1951,6 +1953,16 @@ def allow_status_in_heartbeat():
     return api.request.version.minor >= versions.MINOR_72_HEARTBEAT_STATUS
 
 
+def allow_unhold_verb():
+    """Check if the unhold verb may be passed to the API"""
+    return api.request.version.minor >= versions.MINOR_85_UNHOLD_VERB
+
+
+def allow_service_verb():
+    """Check if the service verb may be passed to the API."""
+    return api.request.version.minor >= versions.MINOR_87_SERVICE
+
+
 def check_allow_deploy_steps(target, deploy_steps):
     """Check if deploy steps are allowed"""
 
@@ -1986,3 +1998,26 @@ def check_allow_clean_disable_ramdisk(target, disable_ramdisk):
 def allow_shards_endpoint():
     """Check if shards endpoint is available."""
     return api.request.version.minor >= versions.MINOR_82_NODE_SHARD
+
+
+def new_continue_inspection_endpoint():
+    """Check if /v1/continue_inspection endpoint is explicitly requested."""
+    return api.request.version.minor >= versions.MINOR_84_CONTINUE_INSPECTION
+
+
+def allow_continue_inspection_endpoint():
+    """Check if /v1/continue_inspection endpoint is available.
+
+    As a special exception, we allow it in the base version so that the API
+    can be used as a drop-in replacement for the Inspector's API.
+    """
+    return (new_continue_inspection_endpoint()
+            or api.request.version.minor == versions.MINOR_1_INITIAL_VERSION)
+
+
+def allow_firmware_interface():
+    """Check if we should support firmware interface and endpoints.
+
+    Version 1.86 of the API added support for firmware interface.
+    """
+    return api.request.version.minor >= versions.MINOR_86_FIRMWARE_INTERFACE
