@@ -23,17 +23,11 @@ import sys
 
 from oslo_config import cfg
 from oslo_log import log
-try:
-    from oslo_reports import guru_meditation_report as gmr
-    from oslo_reports import opts as gmr_opts
-except ImportError:
-    gmr = None
 from oslo_service import service
 
-from ironic.common import profiler
 from ironic.common import rpc_service
 from ironic.common import service as ironic_service
-from ironic import version
+from ironic.common import utils
 
 CONF = cfg.CONF
 
@@ -50,20 +44,43 @@ def warn_about_unsafe_shred_parameters(conf):
                     'Secure Erase. This is a possible SECURITY ISSUE!')
 
 
-def warn_about_agent_token_deprecation(conf):
-    if not conf.require_agent_token:
-        LOG.warning('The ``[DEFAULT]require_agent_token`` option is not '
-                    'set and support for ironic-python-agents that do not '
-                    'utilize agent tokens, along with the configuration '
-                    'option will be removed in the W development cycle. '
-                    'Please upgrade your ironic-python-agent version, and '
-                    'consider adopting the require_agent_token setting '
-                    'during the Victoria development cycle.')
+def warn_about_sqlite():
+    # We are intentionally calling the helper here to ensure it caches
+    # for all future calls.
+    if utils.is_ironic_using_sqlite():
+        LOG.warning('Ironic has been configured to utilize SQLite. '
+                    'This has some restrictions and impacts. You must run '
+                    'as as a single combined ironic process, and some '
+                    'internal mechanisms do not execute such as the hash '
+                    'ring will remain static and the conductor\'s '
+                    '``last_updated`` field will also not update. This is '
+                    'in order to minimize database locking issues present '
+                    'as a result of SQLAlchemy 2.0 and the removal of '
+                    'autocommit support.')
+
+
+def warn_about_max_wait_parameters(conf):
+    max_wait = conf.conductor.max_conductor_wait_step_seconds
+    max_deploy_timeout = conf.conductor.deploy_callback_timeout
+    max_clean_timeout = conf.conductor.clean_callback_timeout
+    error_with = None
+    if max_wait >= max_deploy_timeout:
+        error_with = 'deploy_callback_timeout'
+    if max_wait >= max_clean_timeout:
+        error_with = 'clean_callback_timeout'
+    if error_with:
+        LOG.warning('The [conductor]max_conductor_wait_step_seconds '
+                    'configuration parameter exceeds the value of '
+                    '[conductor]%s, which could create a condition where '
+                    'tasks may timeout. Ironic recommends a low default '
+                    'value for [conductor]max_conductor_wait_step_seconds ',
+                    'please re-evaluate your configuration.', error_with)
 
 
 def issue_startup_warnings(conf):
     warn_about_unsafe_shred_parameters(conf)
-    warn_about_agent_token_deprecation(conf)
+    warn_about_sqlite()
+    warn_about_max_wait_parameters(conf)
 
 
 def main():
@@ -76,14 +93,8 @@ def main():
     assert 'ironic.conductor.manager' not in sys.modules
 
     # Parse config file and command line options, then start logging
-    ironic_service.prepare_service(sys.argv)
-
-    if gmr is not None:
-        gmr_opts.set_defaults(CONF)
-        gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
-    else:
-        LOG.debug('Guru meditation reporting is disabled '
-                  'because oslo.reports is not installed')
+    ironic_service.prepare_service('ironic_conductor', sys.argv)
+    ironic_service.ensure_rpc_transport(CONF)
 
     mgr = rpc_service.RPCService(CONF.host,
                                  'ironic.conductor.manager',
@@ -91,10 +102,14 @@ def main():
 
     issue_startup_warnings(CONF)
 
-    profiler.setup('ironic_conductor', CONF.host)
-
     launcher = service.launch(CONF, mgr, restart_method='mutate')
-    launcher.wait()
+
+    # NOTE(dtantsur): handling start-up failures before launcher.wait() helps
+    # notify systemd about them. Otherwise the launcher will report successful
+    # service start-up before checking the threads.
+    mgr.wait_for_start()
+
+    sys.exit(launcher.wait())
 
 
 if __name__ == '__main__':
