@@ -14,6 +14,7 @@
 
 from oslo_log import log
 
+from ironic.common import async_steps
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common import states
@@ -82,11 +83,8 @@ def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
                                       disable_ramdisk)
     task.node.save()
 
-    # Retrieve BIOS config settings for this node
-    utils.node_cache_bios_settings(task, node)
+    utils.node_update_cache(task)
 
-    # Retrieve Firmware Components for this node if possible
-    utils.node_cache_firmware_components(task)
     # Allow the deploy driver to set up the ramdisk again (necessary for
     # IPA cleaning)
     try:
@@ -195,13 +193,14 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
 
         except Exception as e:
             if isinstance(e, exception.AgentConnectionFailed):
-                if task.node.driver_internal_info.get('cleaning_reboot'):
+                if task.node.driver_internal_info.get(
+                        async_steps.CLEANING_REBOOT):
                     LOG.info('Agent is not yet running on node %(node)s '
                              'after cleaning reboot, waiting for agent to '
                              'come up to run next clean step %(step)s.',
                              {'node': node.uuid, 'step': step})
-                    node.set_driver_internal_info('skip_current_clean_step',
-                                                  False)
+                    node.set_driver_internal_info(
+                        async_steps.SKIP_CURRENT_CLEAN_STEP, False)
                     target_state = (states.MANAGEABLE if manual_clean
                                     else None)
                     task.process_event('wait', target_state=target_state)
@@ -212,7 +211,8 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
                          'executing a command. Error: %(error)s',
                          {'node': task.node.uuid,
                           'error': e})
-                node.set_driver_internal_info('skip_current_clean_step', False)
+                node.set_driver_internal_info(
+                    async_steps.SKIP_CURRENT_CLEAN_STEP, False)
                 target_state = states.MANAGEABLE if manual_clean else None
                 task.process_event('wait', target_state=target_state)
                 return
