@@ -29,6 +29,7 @@ from oslo_utils import excutils
 from oslo_utils import strutils
 from oslo_utils import timeutils
 
+from ironic.common import async_steps
 from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common import faults
@@ -490,9 +491,7 @@ def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
         node.clean_step = {}
         # Clear any leftover metadata about cleaning
         node.del_driver_internal_info('clean_step_index')
-        node.del_driver_internal_info('cleaning_reboot')
-        node.del_driver_internal_info('cleaning_polling')
-        node.del_driver_internal_info('skip_current_clean_step')
+        async_steps.remove_node_flags(node)
         # We don't need to keep the old agent URL, or token
         # as it should change upon the next cleaning attempt.
         wipe_token_and_url(task)
@@ -553,10 +552,8 @@ def wipe_deploy_internal_info(task):
     node.del_driver_internal_info('user_deploy_steps')
     node.del_driver_internal_info('agent_cached_deploy_steps')
     node.del_driver_internal_info('deploy_step_index')
-    node.del_driver_internal_info('deployment_reboot')
-    node.del_driver_internal_info('deployment_polling')
-    node.del_driver_internal_info('skip_current_deploy_step')
     node.del_driver_internal_info('steps_validated')
+    async_steps.remove_node_flags(node)
 
 
 def wipe_cleaning_internal_info(task):
@@ -567,11 +564,9 @@ def wipe_cleaning_internal_info(task):
     node.set_driver_internal_info('clean_steps', None)
     node.del_driver_internal_info('agent_cached_clean_steps')
     node.del_driver_internal_info('clean_step_index')
-    node.del_driver_internal_info('cleaning_reboot')
-    node.del_driver_internal_info('cleaning_polling')
     node.del_driver_internal_info('cleaning_disable_ramdisk')
-    node.del_driver_internal_info('skip_current_clean_step')
     node.del_driver_internal_info('steps_validated')
+    async_steps.remove_node_flags(node)
 
 
 def wipe_service_internal_info(task):
@@ -581,11 +576,9 @@ def wipe_service_internal_info(task):
     node.set_driver_internal_info('service_steps', None)
     node.del_driver_internal_info('agent_cached_service_steps')
     node.del_driver_internal_info('service_step_index')
-    node.del_driver_internal_info('service_reboot')
-    node.del_driver_internal_info('service_polling')
     node.del_driver_internal_info('service_disable_ramdisk')
-    node.del_driver_internal_info('skip_current_service_step')
     node.del_driver_internal_info('steps_validated')
+    async_steps.remove_node_flags(node)
 
 
 def deploying_error_handler(task, logmsg, errmsg=None, traceback=False,
@@ -1117,7 +1110,10 @@ def fast_track_able(task):
             # TODO(TheJulia): Should we check the provisioning/deployment
             # networks match config wise? Do we care? #decisionsdecisions
             and task.driver.storage.should_write_image(task)
-            and task.node.last_error is None)
+            and task.node.last_error is None
+            # NOTE(dtantsur): Fast track makes zero sense for servicing and
+            # may prevent normal clean-up from happening.
+            and task.node.provision_state not in states.SERVICING_STATES)
 
 
 def value_within_timeout(value, timeout):
@@ -1265,14 +1261,8 @@ def update_next_step_index(task, step_type):
     :param step_type: The type of steps to process: 'clean' or 'deploy'.
     :returns: Index of the next step.
     """
-    skip_current_step = task.node.del_driver_internal_info(
-        'skip_current_%s_step' % step_type, True)
-    if step_type == 'clean':
-        task.node.del_driver_internal_info('cleaning_polling')
-    else:
-        task.node.del_driver_internal_info('deployment_polling')
-    task.node.save()
-
+    skip_current_step = async_steps.prepare_node_for_next_step(
+        task.node, step_type)
     return _get_node_next_steps(task, step_type,
                                 skip_current_step=skip_current_step)
 
@@ -1441,18 +1431,18 @@ def store_agent_certificate(node, agent_verify_ca):
         return fname
 
 
-def node_cache_bios_settings(task, node):
+def node_cache_bios_settings(task):
     """Do caching of bios settings if supported by driver"""
     try:
-        LOG.debug('Getting BIOS info for node %s', node.uuid)
+        LOG.debug('Getting BIOS info for node %s', task.node.uuid)
         task.driver.bios.cache_bios_settings(task)
     except exception.UnsupportedDriverExtension:
         LOG.warning('BIOS settings are not supported for node %s, '
-                    'skipping', node.uuid)
-    # TODO(zshi) remove this check when classic drivers are removed
+                    'skipping', task.node.uuid)
     except Exception:
+        # NOTE(dtantsur): the caller expects this function to never fail
         msg = (_('Caching of bios settings failed on node %(node)s.')
-               % {'node': node.uuid})
+               % {'node': task.node.uuid})
         LOG.exception(msg)
 
 
@@ -1474,6 +1464,7 @@ def node_cache_vendor(task):
     except exception.UnsupportedDriverExtension:
         return
     except Exception as exc:
+        # NOTE(dtantsur): the caller expects this function to never fail
         LOG.warning('Unexpected exception when trying to detect vendor '
                     'for node %(node)s. %(class)s: %(exc)s',
                     {'node': task.node.uuid,
@@ -1806,9 +1797,7 @@ def servicing_error_handler(task, logmsg, errmsg=None, traceback=False,
         node.service_step = {}
         # Clear any leftover metadata about cleaning
         node.del_driver_internal_info('service_step_index')
-        node.del_driver_internal_info('servicing_reboot')
-        node.del_driver_internal_info('servicing_polling')
-        node.del_driver_internal_info('skip_current_service_step')
+        async_steps.remove_node_flags(node)
         # We don't need to keep the old agent URL, or token
         # as it should change upon the next cleaning attempt.
         wipe_token_and_url(task)
@@ -1840,3 +1829,23 @@ def node_cache_firmware_components(task):
     except exception.UnsupportedDriverExtension:
         LOG.warning('Firmware Components are not supported for node %s, '
                     'skipping', task.node.uuid)
+    except Exception:
+        # NOTE(dtantsur): the caller expects this function to never fail
+        LOG.exception('Caching of firmware components failed on node %s',
+                      task.node.uuid)
+
+
+def node_update_cache(task):
+    """Updates various cached information.
+
+    Includes vendor, boot mode, BIOS settings and firmware components.
+
+    :param task: A TaskManager instance containing the node to act on.
+    """
+    # FIXME(dtantsur): in case of Redfish, these 4 calls may result in the
+    # System object loaded at least 4 times. "Cache whatever you can" should
+    # probably be a driver call, just not clear in which interface.
+    node_cache_vendor(task)
+    node_cache_boot_mode(task)
+    node_cache_bios_settings(task)
+    node_cache_firmware_components(task)
