@@ -20,13 +20,15 @@ from ironic.conf import auth
 
 VALID_ADD_PORTS_VALUES = {
     'all': _('all MAC addresses'),
-    'active': _('MAC addresses of NIC\'s with IP addresses'),
+    'active': _('MAC addresses of NICs with IP addresses'),
     'pxe': _('only the MAC address of the PXE NIC'),
     'disabled': _('do not create any ports'),
 }
 VALID_KEEP_PORTS_VALUES = {
-    'all': _('keep even ports with MAC\'s not present in the inventory'),
-    'present': _('keep only ports with MAC\'s present in the inventory'),
+    'all': _('keep all ports, even ones with MAC addresses that are not '
+             'present in the inventory'),
+    'present': _('keep only ports with MAC addresses present in '
+                 'the inventory'),
     'added': _('keep only ports determined by the add_ports option'),
 }
 
@@ -69,6 +71,20 @@ opts = [
                 default=True,
                 help=_('Whether to update the ports\' pxe_enabled field '
                        'according to the inspection data.')),
+    cfg.StrOpt('default_hooks',
+               default='ramdisk-error,validate-interfaces,ports,architecture',
+               help=_('A comma-separated lists of inspection hooks that are '
+                      'run by default. In most cases, the operators will not '
+                      'modify this. The default (somewhat conservative) hooks '
+                      'will raise an exception in case the ramdisk reports an '
+                      'error, validate interfaces in the inventory, and create'
+                      ' ports.')),
+    cfg.StrOpt('hooks',
+               default='$default_hooks',
+               help=_('Comma-separated list of enabled hooks for processing '
+                      'pipeline. The default for this is $default_hooks. '
+                      'Hooks can be added before or after the defaults '
+                      'like this: "prehook,$default_hooks,posthook".')),
 ]
 
 
